@@ -1,5 +1,5 @@
 // A mathematical game
-// Copyright (C) 2004 by Christian von Schultz <schultz@linux.nu>
+// Copyright (C) 2004-2005 by Christian von Schultz <schultz@linux.nu>
 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -80,8 +80,8 @@ enum {
 
 //// IDs used by other classes (class name prepended) ////
   HTMLPANEL_BUTTON,		// The button of HtmlPanel is clicked
-  CHOOSEONEPANEL,
-  CHOOSEONEPANEL_LISTCTRL,
+  ONEPANEL,
+  ONEPANEL_ANSWERCTRL,
 
   ID_HIGHEST = wxID_HIGHEST + 1000 };
     
