@@ -32,11 +32,14 @@ SelfCorrecting::SelfCorrecting(MultSim *ms, wxWindow *parent,
   m_answer(answer),
   m_ms(ms),
   wxTextCtrl(parent, -1, wxEmptyString, wxDefaultPosition,
-	     wxDefaultSize, wxTE_RIGHT)
+	     wxDefaultSize, wxTE_RIGHT | wxTE_PROCESS_ENTER)
 {
-  Connect(GetId(), wxEVT_COMMAND_TEXT_UPDATED,
+  Connect(GetId(), wxEVT_COMMAND_TEXT_ENTER,
+ 	  (wxObjectEventFunction) (wxEventFunction)
+ 	  (wxCommandEventFunction) &SelfCorrecting::OnTextEnter);
+  Connect(GetId(), wxEVT_KILL_FOCUS,
 	  (wxObjectEventFunction) (wxEventFunction)
-	  (wxCommandEventFunction) &SelfCorrecting::OnCorrect);
+	  (wxFocusEventFunction) &SelfCorrecting::OnKillFocus);
 
   if(! ms_number++)		// Ensures that the first one gets focus.
   {
@@ -48,7 +51,11 @@ SelfCorrecting::~SelfCorrecting() throw()
 {
   Disconnect(GetId(), wxEVT_COMMAND_TEXT_UPDATED,
 	     (wxObjectEventFunction) (wxEventFunction)
-	     (wxCommandEventFunction) &SelfCorrecting::OnCorrect);
+	     (wxCommandEventFunction) &SelfCorrecting::OnTextEnter);
+
+  Disconnect(GetId(), wxEVT_KILL_FOCUS,
+	     (wxObjectEventFunction) (wxEventFunction)
+	     (wxFocusEventFunction) &SelfCorrecting::OnKillFocus);
 
   --ms_number;
 }
@@ -61,17 +68,29 @@ wxString SelfCorrecting::GetValue() const
     return wxTextCtrl::GetValue();
 }
 
-void SelfCorrecting::OnCorrect(wxCommandEvent &ev)
+void SelfCorrecting::OnKillFocus(wxFocusEvent &ev)
+{
+  Correct();
+  ev.Skip();
+}
+
+void SelfCorrecting::OnTextEnter(wxCommandEvent &ev)
+{
+  Correct();
+  ev.Skip();
+}
+
+void SelfCorrecting::Correct() throw()
 {
   if(wxTextCtrl::GetValue() == m_answer)
   {
     SetEditable(false);
     SetValue(m_answer + _(": correct"));
-  }
-  else if(wxTextCtrl::GetValue() == m_answer + _(": correct"))
-  {
-    SetEditable(false);
     m_ms->OneMoreCorrect();
   }
+//   else if(wxTextCtrl::GetValue() == m_answer + _(": correct"))
+//   {
+//     SetEditable(false);
+//     m_ms->OneMoreCorrect();
+//   }
 }
-
