@@ -35,7 +35,10 @@ public:
   SelfCorrecting(MultSim *ms, wxWindow *parent, const wxString &answer) throw();
   ~SelfCorrecting() throw();
 
-  void OnCorrect(wxCommandEvent &ev);
+  void OnKillFocus(wxFocusEvent &ev);
+  void OnTextEnter(wxCommandEvent &ev);
+
+  void Correct() throw();
 
   wxString GetValue() const;
 
